@@ -589,13 +589,16 @@ class FlushCommand(object):
     def execute(self):
         table = self.table
         query = transaction._rpc(self.connection).query(kind=table, namespace=self.namespace)
-
         query.keys_only()
 
-        results = [x.key for x in query.fetch()]
+        # The local datastore emulator explodes if you try to delete more than 500
+        # things in a single batch. So we just iterate in batches of 500.
+        limit = 500
+
+        results = [x.key for x in query.fetch(limit=limit)]
         while results:
             transaction._rpc(self.connection).delete(results)
-            results = [x.key for x in query.fetch()]
+            results = [x.key for x in query.fetch(limit=limit)]
 
 
 def reserve_id(connection, kind, id_or_name, namespace):
@@ -604,7 +607,7 @@ def reserve_id(connection, kind, id_or_name, namespace):
         return
 
     gclient = connection.connection.gclient
-    gclient.reserve_ids(gclient.key(kind, id_or_name, namespace=namespace), 1)
+    gclient.reserve_ids_sequential(gclient.key(kind, id_or_name, namespace=namespace), 1)
 
 
 def perform_unique_checks(model, rpc, primary, test_fn):
